# Trend test code from : Increasing numbers of killer whale 
#individuals use fisheries as feeding opportunities 
# within subantarctic populations

# author: Morgane Amelot

library(ggplot2)
library(plyr)
library(dplyr)
library(nlme)
library(faraway)

###Crozet regular tendance test 

load("CrozetFinrevfinfin.Rdata")

# weights calculation 
wC1<-1/resage[17:32,2]
wD1<-1/resage[33:48,2]

# depredating individuals bounds
low_ND1=resage[33:48,3]
up_ND1=resage[33:48,4]
# non depredating individuals bounds
low_NC1=resage[17:32,3]
up_NC1=resage[17:32,4]

#number of depredating and non depredating 
NC1=resage[17:32,1]
ND1=resage[33:48,1]


Year=c(1:16)
Year<-seq(2003,2018)
Year2<-seq(2003,2018)
ad=acf(ND1)
ac=acf(NC1)

#data frames 
D1=data.frame(ND1,Year,wD1,low_ND1,up_ND1)
D1=data.frame(ND1,Year2,wD1,low_ND1,up_ND1)
C1=data.frame(NC1,Year,wC1,low_NC1,up_NC1)
C1=data.frame(NC1,Year2,wC1,low_NC1,up_NC1)

# Depredating individuals
#logistic model 
model1_D<-gnls(ND1~SSlogis(Year,Asym,xmid,scal), data=D1,
               weights =~wD1, correlation=corAR1(0.75))
#linear model time 
model2_D<-gls(ND1~Year, data=D1,weights =~wD1, correlation=corAR1(0.75))
summary(model2_D)
# linear model 
model3_D<-gls(ND1~1, data=D1,weights =~wD1, correlation=corAR1(0.75))
#model comparisons
AIC(model1_D,model2_D,model3_D)

#non depredating individuals 
#logistic model 
model1_C<-gnls(NC1~SSlogis(Year,Asym,xmid,scal), data=C1,
               weights =~wC1, correlation=corAR1(0.75))
#linear model year
model2_C<-gls(NC1~Year, data=C1,weights =~wC1, correlation=corAR1(0.75))
summary(model2_C)
#linear model 
model3_C<-gls(NC1~1, data=C1,weights =~wC1, correlation=corAR1(0.75))
AIC(model1_C,model2_C,model3_C)


####Type-D killer whales 


load("DFinrevfinfin.Rdata")

#weights calculation
wD2<-1/resageD[17:32,2]

# bounds and number of individuals
low_ND2=resageD[17:32,3]
up_ND2=resageD[17:32,4]
ND2=resageD[17:32,1]
Year=c(1:16)
Year<-seq(2003,2018)
Year2<-seq(2009,2018)
ad=acf(ND2)

#dataframe 
DD1=data.frame(ND2,Year,wD2)
DD1=data.frame(ND2=ND2[7:16],Year2=Year2,wd2=wD2[7:16], low_ND2=low_ND2[7:16],up_ND2=up_ND2[7:16])
#logistic model 
model1_D<-gnls(ND2~SSlogis(Year2,Asym,xmid,scal), data=DD1,
               weights =~wd2, correlation=corAR1(0.75))
#linear model year
model2_D<-gls(ND2~Year2, data=DD1,weights =~wd2, correlation=corAR1(0.75))
summary(model2_D)
#linear model 
model3_D<-gls(ND2~1, data=DD1,weights =~wd2, correlation=corAR1(0.75))
#model comparison 
AIC(model1_D,model2_D,model3_D)



